#//-----------------------------------------------
#//TUSB-KxxRL用サンプルプログラム
#// 処理関数等
#//
#//2024_04_10　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------

import tkinter as tk
import threading
from tkinter import messagebox

def ShowInfo(str):
    """文字列を表示する"""
    messagebox.showinfo("",str)
    
def GetLabel(master,text,relx,rely):
    """ラベルを作成する
    
    arguments:
    master      ----    配置ペアレント
    text        ----    表示する文字列
    relx        ----    X座標相対位置(左端)
    rely        ----    Y座標相対位置(上下中央)

    returns:
    Label       ----    生成されたラベルインスタンス
    """
    label = tk.Label(master,text=text)
    label.place(relx=relx,rely=rely,anchor=tk.W)
    return label

def GenTkVarList(N,cls,initval):
    """Tkinter Var list generator with value initialize
    
    arguments:
    N           ----    list length
    cls         ----    tkinter variable class
    initval     ----    initial value
    
    returns:
    list        ----    generated list
    """
    ret = list()
    for i in range(N):
        ret.append(cls(value=initval))
    return ret

def GetChkBox(master,text,relx,rely,val):
    """チェックボックスを生成する
    
    arguments:
    master      ----    配置ペアレント
    text        ----    表示する文字列
    relx        ----    X座標相対位置(左端)
    rely        ----    Y座標相対位置(上下中央)
    val         ----    variableを対応させるwidget変数(例 BooleanVar())

    returns:
    Checkbutton ----    生成されたチェックボックスのインスタンス
    """
    chkbox = tk.Checkbutton(master,text=text,variable=val)
    chkbox.place(relx=relx,rely=rely,anchor=tk.W)
    return chkbox

def IsBitSet(data,bit):
    if ((data>>bit) & 1) == 1:return True
    else:return False

def GenList(N,initval):
    """list generator with value initialize"""
    ret = list()
    for i in range(N):
        ret.append(initval)
    return ret