#//-----------------------------------------------
#//TUSB-KxxRL用サンプルプログラム
#//Python 用モジュール
#//
#//2024_04_10　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------
import TUSBKRL
import sys

from SpFuncs import *
from functools import partial

class Tusbkrl_Device:
    """TUSB-KINSxx Device Control"""

    DevId = None
    lock = threading.Lock() # デバイスコマンドが同時実行されないために使用するロック

    def __init__(self,DevId):
        """constructor
                
        arguments:
        DevId           ----    Device id 0~15
        """
        ret = TUSBKRL.TUSBKRL_Device_Open(DevId)
        if ret == 0:
            self.DevId = DevId
            self.form.protocol("WM_DELETE_WINDOW", self.DevClose)   # フォームが閉じられる時に処理を行うため
            if self.DevInit():
                return
            TUSBKRL.TUSBKRL_Device_Close(DevId)
        ShowInfo(TUSBKRL.GetErrMessage(ret))
        self.form.destroy()                             # 何か問題が有ったら終了とする
    
    def DevInit(self):
        """デバイスの状態を確認して画面表示に反映する"""
        self.form.title('TUSB-KxxRL ID='+str(self.DevId))
        # 出力ビット状態ON OFFを読み出してチェックボックスに反映する
        ret = TUSBKRL.TUSBKRL_Read(self.DevId)
        if ret[0] != 0:
            ShowInfo(TUSBKRL.GetErrMessage(ret[0]))
            return False
        for bit in range(8):
            self.ChkBit[bit].set(IsBitSet(ret[1],bit))
        # ラジオボタンとチェックボックス変更時のコマンドハンドラを設定する
        for bit in range(8):
            self.chkb[bit].config(command=partial(self.Check_on,bit=bit))
        return True

    def DevClose(self):
        """デバイスを閉じる時の処理"""
        if self.DevId != None:
            TUSBKRL.TUSBKRL_Device_Close(self.DevId)
            self.form.destroy()
    
    def Check_on(self,bit):
        """出力が変更された時のハンドラ"""
        data = 1 if self.ChkBit[bit].get() else 0
        if self.lock.acquire(timeout=1):
            ret = TUSBKRL.TUSBKRL_BitSet(self.DevId,bit,data)
            self.lock.release()
            if ret != 0:
                ShowInfo(TUSBKRL.GetErrMessage(ret))

    # form generation ---------------------------
    form = tk.Tk()
    form.geometry('160x204')
    form.title('TUSB-KxxRL Sample Program')
    form.attributes("-toolwindow",True)

    chkb = GenList(8,None)                      # チェックボックス
    ChkBit = GenTkVarList(8,tk.BooleanVar,False)# チェックボックスのチェック状態

    # 表示ラベル
    GetLabel(form,"Output",0.1,0.04)
    # チェックボックスと入力表示
    for bit in range(8):
        chkb[bit] = GetChkBox(form,str(bit),0.18,0.2+0.1*bit,ChkBit[bit])
    
# テスト用 ---------------------------------
if __name__=="__main__":
    DevId = 0
    if( len(sys.argv) >= 2 ):
        if sys.argv[1].isdigit():
            DevId = int(sys.argv[1])    # コマンドライン引数でID設定
    tmp = Tusbkrl_Device(DevId=DevId)
    tmp.form.mainloop()

